==> igniteui-react-charts-16.4.1.tgz: package/ES2015/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-react-core/ES2015/Brush";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, runOn, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { ArrayExtension } from "igniteui-react-core/ES2015/ArrayExtension";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
export class WaterfallSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.ab = WaterfallSeries.$;
    }
    bf() {
        return new WaterfallSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.p7 = a;
    }
    preferredCategoryMode(a) {
        return 2;
    }
    get_cz() {
        return true;
    }
    get cz() {
        return this.get_cz();
    }
    i9(a, b) {
        super.i9(a, b);
        this.qi = a;
        this.qj = b;
    }
    k0() {
        return this.qi;
    }
    get_nm() {
        return true;
    }
    get nm() {
        return this.get_nm();
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.i4(false);
                break;
        }
    }
    df(a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ll(a) {
        if (this.p7 == null || this.p7.c5 == null || this.p7.c5.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        let b = this.p7.c5;
        let c = this.k7(a);
        let d = -1;
        let e = this.xAxis.b8;
        let f = this.lp.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                let h = this.p7.dc(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                let h = this.p7.dc(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        let g = d;
        let h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        let i = this.qk(g);
        let j = this.qk(d);
        let k = this.qk(h);
        let l = i.left + i.width / 2;
        let m = j.left + j.width / 2;
        let n = k.left + k.width / 2;
        let o = Math.abs(l - c.x);
        let p = Math.abs(m - c.x);
        let q = Math.abs(n - c.x);
        let r = i.containsPoint(c);
        let s = j.containsPoint(c);
        let t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    }
    qk(a) {
        return this.p7.db(a);
    }
    m7() {
        return 1;
    }
    ho(a, b) {
        super.ho(a, b);
        this.p7.c5.count = 0;
    }
    ec() {
        return this.po.jk(this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    }
    oe(a, b) {
        let c = b;
        super.oe(a, b);
        let d = b.bq;
        let e = b.bp;
        let f = this.getEffectiveViewport1(b);
        let g = this.po.jk(d, e, f);
        let h = this.p8;
        let i = this.p9;
        let j;
        let k = this.ox(b);
        let l = NaN;
        let m = c.c5;
        let n;
        let o = 0;
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.p8;
        this.m5.q = this.p9;
        this.m5.j = this.p8;
        this.m5.k = this.p9;
        let p = false;
        let q = this.m5.c;
        if (q != null) {
            p = true;
        }
        let r = this.po.cc;
        let s = this.valueColumn.count;
        let t = a.f;
        let u = this.po;
        let v = new ScalerParams(0, d, e, this.po.b8, f);
        let w = this.ku;
        let x = this.qi;
        let y = this.kv;
        let z = this.qj || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            let aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.da(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.oa(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.da(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.m5.al = w;
                    this.m5.ah = w;
                    this.m5.am = y;
                    this.m5.ai = y;
                    this.m5.f = false;
                    if (p) {
                        this.oa(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (let ab = 1; ab < a.f.count; ++ab) {
            let ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            let ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.da(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.m5.al = w;
                this.m5.ah = w;
                this.m5.am = y;
                this.m5.ai = y;
                this.m5.f = false;
                if (l > ad) {
                    if (p) {
                        this.oa(t, ab, s, u, v, b.n);
                    }
                }
                else {
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.oa(t, ab, s, u, v, b.n);
                    }
                }
                this.m5.ae(n, false, false, false, false);
                n.al = this.m5.j;
                n.am = this.m5.k;
                l = ad;
            }
        }
        m.count = o;
        b.cs(a);
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:qi:qe', [Brush.$, null], 'NegativeOutline:qj:qf', [Brush.$, null], 'RadiusX:p8:qg', [1, 2], 'RadiusY:p9:qh', [1, 2]]);
export class WaterfallSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c4 = null;
        this.c6 = null;
        this.dd = new Rectangle();
        this.c5 = null;
        this.c4 = a;
        this.c5 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.de);
            $ret.activate = runOn(this, this.c7);
            $ret.disactivate = runOn(this, this.c9);
            $ret.destroy = runOn(this, this.c8);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.c6 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.c4.qi = ((() => {
                let $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.c4.qj = ((() => {
                let $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.e.bj = 5;
        }
    }
    de() {
        let a = new Rectangle();
        this.c6.add(a);
        a._visibility = 1;
        return a;
    }
    c7(a) {
        a._visibility = 0;
    }
    c9(a) {
        a._visibility = 1;
    }
    c8(a) {
        this.c6.remove(a);
    }
    da(a, b, c) {
        let d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.an();
        }
    }
    z(a) {
        return this.c6._inner[a];
    }
    y(a) {
        let b = this.c6._inner[a];
        this.dd._visibility = b._visibility;
        this.dd.n = b.n;
        this.dd.o = b.o;
        this.dd.width = b.width;
        this.dd.height = b.height;
        let c = this.bl(a);
        this.dd._fill = c;
        this.dd._stroke = c;
        this.dd.ac = this.e.eu + 3;
        return this.dd;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.c6.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.c5.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            let f = "Negative";
            if (e._fill == this.e.ku) {
                f = "Positive";
            }
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", f]);
        }
        b++;
    }
    db(a) {
        let b = this.c5.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    }
    dc(a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    }
}
WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.WaterfallSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.WaterfallSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-react-core/ES2015/Brush";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, runOn, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { ArrayExtension } from "igniteui-react-core/ES2015/ArrayExtension";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
export class WaterfallSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.ab = WaterfallSeries.$;
    }
    bf() {
        return new WaterfallSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.p8 = a;
    }
    preferredCategoryMode(a) {
        return 2;
    }
    get_cz() {
        return true;
    }
    i9(a, b) {
        super.i9(a, b);
        this.qj = a;
        this.qk = b;
    }
    k0() {
        return this.qj;
    }
    get_nm() {
        return true;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.i4(false);
                break;
        }
    }
    df(a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ll(a) {
        if (this.p8 == null || this.p8.c7 == null || this.p8.c7.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        let b = this.p8.c7;
        let c = this.k7(a);
        let d = -1;
        let e = this.xAxis.b8;
        let f = this.lp.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                let h = this.p8.de(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, (g) => {
                let h = this.p8.de(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        let g = d;
        let h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        let i = this.ql(g);
        let j = this.ql(d);
        let k = this.ql(h);
        let l = i.left + i.width / 2;
        let m = j.left + j.width / 2;
        let n = k.left + k.width / 2;
        let o = Math.abs(l - c.x);
        let p = Math.abs(m - c.x);
        let q = Math.abs(n - c.x);
        let r = i.containsPoint(c);
        let s = j.containsPoint(c);
        let t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    }
    ql(a) {
        return this.p8.dd(a);
    }
    m7() {
        return 1;
    }
    ho(a, b) {
        super.ho(a, b);
        this.p8.c7.count = 0;
    }
    ec() {
        return this.pp.jk(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    }
    of(a, b) {
        let c = b;
        super.of(a, b);
        let d = b.bs;
        let e = b.br;
        let f = this.getEffectiveViewport1(b);
        let g = this.pp.jk(d, e, f);
        let h = this.p9;
        let i = this.qa;
        let j;
        let k = this.oy(b);
        let l = NaN;
        let m = c.c7;
        let n;
        let o = 0;
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.p9;
        this.m5.q = this.qa;
        this.m5.j = this.p9;
        this.m5.k = this.qa;
        let p = false;
        let q = this.m5.c;
        if (q != null) {
            p = true;
        }
        let r = this.pp.cc;
        let s = this.valueColumn.count;
        let t = a.f;
        let u = this.pp;
        let v = new ScalerParams(0, d, e, this.pp.b8, f);
        let w = this.ku;
        let x = this.qj;
        let y = this.kv;
        let z = this.qk || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            let aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.dc(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.ob(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.dc(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.m5.al = w;
                    this.m5.ah = w;
                    this.m5.am = y;
                    this.m5.ai = y;
                    this.m5.f = false;
                    if (p) {
                        this.ob(t, 0, s, u, v, b.n);
                    }
                    this.m5.ae(n, false, false, false, false);
                    n.al = this.m5.j;
                    n.am = this.m5.k;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (let ab = 1; ab < a.f.count; ++ab) {
            let ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            let ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.dc(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.m5.al = w;
                this.m5.ah = w;
                this.m5.am = y;
                this.m5.ai = y;
                this.m5.f = false;
                if (l > ad) {
                    if (p) {
                        this.ob(t, ab, s, u, v, b.n);
                    }
                }
                else {
                    this.m5.al = x;
                    this.m5.ah = x;
                    this.m5.am = z;
                    this.m5.ai = z;
                    this.m5.f = true;
                    if (p) {
                        this.ob(t, ab, s, u, v, b.n);
                    }
                }
                this.m5.ae(n, false, false, false, false);
                n.al = this.m5.j;
                n.am = this.m5.k;
                l = ad;
            }
        }
        m.count = o;
        b.cu(a);
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:qj:qf', [Brush.$, null], 'NegativeOutline:qk:qg', [Brush.$, null], 'RadiusX:p9:qh', [1, 2], 'RadiusY:qa:qi', [1, 2]]);
export class WaterfallSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.c8 = null;
        this.df = new Rectangle();
        this.c7 = null;
        this.c6 = a;
        this.c7 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.dg);
            $ret.activate = runOn(this, this.c9);
            $ret.disactivate = runOn(this, this.db);
            $ret.destroy = runOn(this, this.da);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.c8 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.c6.qj = ((() => {
                let $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.c6.qk = ((() => {
                let $ret = new Brush();
                $ret.fill = "#C62828";
                return $ret;
            })());
            this.e.bj = 5;
        }
    }
    dg() {
        let a = new Rectangle();
        this.c8.add(a);
        a._visibility = 1;
        return a;
    }
    c9(a) {
        a._visibility = 0;
    }
    db(a) {
        a._visibility = 1;
    }
    da(a) {
        this.c8.remove(a);
    }
    dc(a, b, c) {
        let d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.an();
        }
    }
    z(a) {
        return this.c8._inner[a];
    }
    y(a) {
        let b = this.c8._inner[a];
        this.df._visibility = b._visibility;
        this.df.n = b.n;
        this.df.o = b.o;
        this.df.width = b.width;
        this.df.height = b.height;
        let c = this.bm(a);
        this.df._fill = c;
        this.df._stroke = c;
        this.df.ac = this.e.eu + 3;
        return this.df;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.c8.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.c7.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            let f = "Negative";
            if (e._fill == this.e.ku) {
                f = "Positive";
            }
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", f]);
        }
        b++;
    }
    dd(a) {
        let b = this.c7.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    }
    de(a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    }
}
WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
